numpy.iinfo
===========

.. currentmodule:: numpy

.. autoclass:: iinfo

   

   .. HACK
      .. autosummary::
         :toctree:
      
         iinfo.__init__



   

   .. HACK
      .. autosummary::
         :toctree:
      
         iinfo.max
         iinfo.min

